# pyco

[https://pyco.nl](https://pyco.nl)

Civiel Technisch ontwerpen in Python.

Jara van Veldhoven 2020-2023.

## Installatie

De pyco bibliotheek is afhankelijk van onderstaande externe bibliotheken:

* numpy (https://numpy.org)
* pandas (https://pandas.pydata.org/) 
* matplotlib (https://matplotlib.org/) 
* IPython (https://ipython.org/)

Je kan de pyco.nl bibliotheek installeren vanuit PyPi met `pip`.

    pip install pyconl

## Documenten

[pyco handleiding](https://github.com/ornor/pyco/blob/master/docs/handleiding/pyco_handleiding.md).
